## Dash Labs tech preview
This repository contains a work-in-progress technical preview of potential future Dash features.

## Documentation
The documentation for Dash Labs can be found in the [docs/](./docs/) directory.
  - [01-Overview.md](https://github.com/plotly/dash-labs/blob/main/docs/01-Overview.md)  

 _Archived in dash-labs v0.4.0:_
  - [02-CallbackEnhancements.md](https://github.com/plotly/dash-labs/blob/main/docs/02-CallbackEnhancements.md)
  - [03-TemplateLayoutSystem.md](https://github.com/plotly/dash-labs/blob/main/docs/03-TemplateLayoutSystem.md)
  - [04-PredefinedTemplates.md](https://github.com/plotly/dash-labs/blob/main/docs/04-PredefinedTemplates.md)
  - [05-ComponentPlugingPattern.md](https://github.com/plotly/dash-labs/blob/main/docs/05-ComponentPlugingPattern.md)
  - [06-TemplateIntegrationAndMigration.md](https://github.com/plotly/dash-labs/blob/main/docs/06-TemplateIntegrationAndMigration.md)
  - [07-LongCallback.md](https://github.com/plotly/dash-labs/blob/main/docs/07-LongCallback.md)

_New in dash-labs v1.0.0:_
  - [08-MultiPageDashApp.md](https://github.com/plotly/dash-labs/blob/main/docs/08-MultiPageDashApp.md)
  - [09-MultiPageDashAppExamples.md](https://github.com/plotly/dash-labs/blob/main/docs/09-MultiPageDashAppExamples.md)

Examples and demos are located in the [docs/demos](./docs/demos) directory.

## Installation
To install the latest version of dash-labs:

```
$ pip install -U dash-labs
```

To install the archived version:
```
$ pip install dash-labs==0.4.0
```
We also recommend installing Pandas, which is required by Plotly Express and used in many of our examples.
